@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from copy import copy
 from importlib.abc import FileLoader
 from importlib.util import module_from_spec
 from importlib.util import spec_from_loader
@@ -102,6 +103,13 @@ class AddonsLoader:
         self.files_repo = files_repo
         self.store = store
 
+    async def update_store(self, middlewares):
+        to_sent = [copy(mdw) for mdw in middlewares]
+        for mdw in to_sent:
+            mdw.imported = None
+        await self.store.set_item("addon", to_sent, send_event=False)
+        await self.store._channel.produce(StoreUpdateEvent("addon", to_sent, True))
+
     async def _import_addon(self, pl: ApiAddon):
         middlewares = await self.store.get_item("addon") if await self.store.get_item("addon") else []
         try:
@@ -134,7 +142,8 @@ class AddonsLoader:
             if middlewares and pl in middlewares:
                 middlewares.remove(pl)
             middlewares.append(pl)
-            await self.store.set_item("addon", middlewares, obj=True)
+            # await self.store.set_item("addon", middlewares, obj=True)
+            await self.update_store(middlewares)
             return pl
 
     async def discover_addons(self):
@@ -147,7 +156,8 @@ class AddonsLoader:
         for mdw in mdws:
             if mdw.filename != filename:
                 new_mdws.append(mdw)
-        await self.store.set_item("addon", new_mdws, obj=True)
+        # await self.store.set_item("addon", new_mdws, obj=True)
+        await self.update_store(new_mdws)
         await self.import_addons()
 
     async def add_new_addon(self, filename: str):
@@ -168,7 +178,7 @@ class AddonsLoader:
                     cell_plugins.append(pl)
             return cell_plugins
 
-    async def find_addon_by_name(self, name: str) -> List[ApiAddon]:
+    async def find_addon_by_name(self, name: str) -> ApiAddon:
         middlewares = await self.store.get_item("addon")
         if not middlewares:
             return []
