@@ -188,11 +188,12 @@ class App(Generic[GenericDependencyContainer]):
     #
     # def before_resources_init(self, listener: AppListener):
     #     self._add_listener("before_resource", listener)
-    #
-    # def before_app_start(self):
-    #     pass
+
+    async def before_app_run(self):
+        await self.container.before_app_run()
 
     def run(self):
+        asyncio.run(self.before_app_run())
         self._set_sanic_confs()
         self._configure_sanic_main()
         self._configure_sanic_worker()
