@@ -1,5 +1,5 @@
 import asyncio
-from asyncio import Future
+from asyncio import Future, CancelledError
 from typing import Dict, Any, List
 
 import loguru
@@ -151,4 +151,7 @@ class IDispatcherIsolate(Isolate):
     async def work(self, **kwargs) -> None:
         if self.dispatcher.scheduler:
             self.dispatcher.scheduler.perform()
-        await asyncio.wait(self.dispatcher.perform())
+        try:
+            await asyncio.wait(self.dispatcher.perform())
+        except CancelledError:
+            pass
\ No newline at end of file
