@@ -67,6 +67,13 @@ class DatabaseResource(Resource, Generic[GenericConfig]):
     async def shutdown(self) -> None:
         await connections.close_all()
 
+    async def before_app_run(self, config: GenericConfig, *args, **kwargs):
+        if config.database.with_migrations:
+            await self.init(config)
+            await self.shutdown()
+            config.database.with_migrations = False
+            self._inited = False
+
     async def _migrations(self, schema_exists: bool, command):
         path_exists = os.path.exists(os.path.join(os.getcwd(), self.db_conf.migrations_path)) and os.listdir(
             os.path.join(os.getcwd(), self.db_conf.migrations_path))
