@@ -23,6 +23,9 @@ class Resource:
     async def shutdown(self):
         raise NotImplementedError
 
+    async def before_app_run(self, config: GenericConfig, *args, **kwargs):
+        pass
+
     @property
     def ready(self):
         return self._inited
